Gender - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Gender

> Gender includes the social, psychological, cultural and behavioral aspects of being a man, woman, or other gender identity.

From gender on Wikipedia

Genders inherit from `betty.ancestry.gender.Gender`.

## Built-in genders

`female` (`betty.ancestry.gender.genders.Female`)

  A person who is female.

`male` (`betty.ancestry.gender.genders.Male`)

  A person who is male.

`non-binary` (`betty.ancestry.gender.genders.NonBinary`)

  A person who is non-binary.

`unknown` (`betty.ancestry.gender.genders.Unknown`)

  A person whose gender is unknown.

## See also

- Gender plugins